<?php

namespace OCA\News\Vendor\fivefilters\Readability\Nodes\DOM;

use OCA\News\Vendor\fivefilters\Readability\Nodes\NodeTrait;
class DOMProcessingInstruction extends \DOMProcessingInstruction
{
    use NodeTrait;
}
